/*****************************************************************************
* File Name: main.c
*
* Version: 1.00
*
* Description: This code example demonstrates how to implement a low-power 
*              CapSense button with an average current consumption of 6uA
*              per button. 

* Related Document: CE210291.pdf 
*
* Hardware Dependency: See code example document CE210291
*
******************************************************************************
* Copyright (2016), Cypress Semiconductor Corporation.
******************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*****************************************************************************/

/*******************************************************************************
*   Included Headers
*******************************************************************************/
#include "project.h"

/*****************************************************************************
* MACRO Definitions
*****************************************************************************/   

/* Refresh interval in milliseconds for fast scan mode */


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  main() performs the following functions:
*  1. Initializes the CapSense and SCB blocks.
*  2. Scans button sensor at either fast refresh rate or slow refresh rate.
*
*******************************************************************************/
int main()
{   
   
    uint8 interruptState;
    /* Enable global interrupts for CapSense operation */
    CyGlobalIntEnable;
   
    /* Start EZI2C block */
    EZI2C_Start();
    
    /* Set up communication data buffer to CapSense data structure to 
     * expose to I2C master at primary slave address request        
     */
    EZI2C_EzI2CSetBuffer1(sizeof(CapSense_dsRam), sizeof(CapSense_dsRam),\
                         (uint8 *)&CapSense_dsRam);

    /* Start CapSense block - Initializes CapSense data structure and 
     * performs first scan of all widgets/sensors to set up sensors
     * baselines 
     */
    CapSense_Start();

    /* Configure button sensor parameters and connect it to AMUXBUS */
   // CapSense_CSDSetupWidgetExt(CapSense_BUTTON0_WDGT_ID, CapSense_BUTTON0_SNS0_ID);
    CapSense_ScanAllWidgets();
    
    /* Watchdog is used to control the loop time in this project and watchdog
    *  is set to generate interrupt at every LOOP_TIME_FASTSCANMODE in fast scan mode  
    *  and at LOOP_TIME_SLOWSCANMODE in slow scan mode
    */

    
    for(;;)
    {
       
     // interruptState=CyEnterCriticalSection();
        if(CapSense_NOT_BUSY==CapSense_IsBusy())
        {
     //   CyExitCriticalSection(interruptState);
       
        
        CapSense_ProcessAllWidgets();
       
     
        if(CapSense_IsAnyWidgetActive())
        {
            
            
            if(CapSense_IsWidgetActive(CapSense_BUTTON0_WDGT_ID))
            {
             Pin_1_Write(0); 
            
            }
             else
            {
             Pin_1_Write(1); 
            }
            if(CapSense_IsWidgetActive(CapSense_BUTTON1_WDGT_ID))
            {
             Pin_2_Write(0); 
            
            }
            else
            {
                 Pin_2_Write(1);
            }
        
        }
        
            CapSense_RunTuner();
        CapSense_ScanAllWidgets();
        
        
        }
      }
}    

/*******************************************************************************
* Function Name: EnterDeepSleepLowPowerMode
********************************************************************************
* Summary:
*  Put the device to DeepSleep power mode. Reconfigures the Components for 
*  normal operation after wake-up. 
*
* Parameters:
*  void
*
* Return:
*  void
*
* Theory: Before going to deep sleep, the API checks for any
*         I2C activity and waits till the I2C transaction is complete before 
*         the device is put to deep sleep. 
*
* Side Effects: None
*
* Note:
*
*******************************************************************************/


/* [] END OF FILE */
